You are viewing a plain text version of this content. The canonical link for it is here.
Posted to cvs@cocoon.apache.org by cz...@apache.org on 2006/03/26 13:22:16 UTC

svn commit: r388896 - in /cocoon/trunk/cocoon-core/src: main/java/org/apache/cocoon/ main/java/org/apache/cocoon/components/treeprocessor/sitemap/ main/java/org/apache/cocoon/core/ main/java/org/apache/cocoon/core/container/spring/ main/java/org/apache...

Author: cziegeler
Date: Sun Mar 26 03:22:11 2006
New Revision: 388896

URL: http://svn.apache.org/viewcvs?rev=388896&view=rev
Log:
Finish hierarchical settings
Add local source resolver to bean factory

Modified:
    cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/Constants.java
    cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/components/treeprocessor/sitemap/SitemapLanguage.java
    cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/CoreUtil.java
    cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/MutableSettings.java
    cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/Settings.java
    cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/BeanFactoryFactoryImpl.java
    cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/BeanFactoryUtil.java
    cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/CocoonSettingsConfigurer.java
    cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/generation/StatusGenerator.java
    cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/sitemap/impl/AbstractVirtualSitemapComponent.java
    cocoon/trunk/cocoon-core/src/test/java/org/apache/cocoon/core/container/ContainerTestCase.java

Modified: cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/Constants.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/Constants.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================
--- cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/Constants.java (original)
+++ cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/Constants.java Sun Mar 26 03:22:11 2006
@@ -197,9 +197,6 @@
     public static final String CONTEXT_CLASSPATH = "classpath";
 
 
-    /** Application <code>Context</code> key for the current environment URI */
-    public static final String CONTEXT_ENV_URI = "env-uri";
-
     /** Application <code>Context</code> key for the current environment prefix */
     public static final String CONTEXT_ENV_PREFIX = "env-prefix";
 

Modified: cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/components/treeprocessor/sitemap/SitemapLanguage.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/components/treeprocessor/sitemap/SitemapLanguage.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================
--- cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/components/treeprocessor/sitemap/SitemapLanguage.java (original)
+++ cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/components/treeprocessor/sitemap/SitemapLanguage.java Sun Mar 26 03:22:11 2006
@@ -649,7 +649,6 @@
         // Create sub-context for this sitemap
         DefaultContext newContext = new DefaultContext(this.context);
         Environment env = EnvironmentHelper.getCurrentEnvironment();
-        newContext.put(Constants.CONTEXT_ENV_URI, env.getURI());
         newContext.put(Constants.CONTEXT_ENV_PREFIX, env.getURIPrefix());
         // FIXME How to get rid of EnvironmentHelper?
         newContext.put(Constants.CONTEXT_ENV_HELPER, getProcessor().getWrappingProcessor()

Modified: cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/CoreUtil.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/CoreUtil.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================
--- cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/CoreUtil.java (original)
+++ cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/CoreUtil.java Sun Mar 26 03:22:11 2006
@@ -613,7 +613,7 @@
         env.settings = this.settings;
         ConfigurableBeanFactory rootContext = BeanFactoryUtil.createRootBeanFactory(env);
         ConfigurationInfo result = ConfigReader.readConfiguration(settings.getConfiguration(), env);
-        ConfigurableBeanFactory mainContext = BeanFactoryUtil.createBeanFactory(env, result, rootContext, true);
+        ConfigurableBeanFactory mainContext = BeanFactoryUtil.createBeanFactory(env, result, null, rootContext, true);
 
         return mainContext;
     }

Modified: cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/MutableSettings.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/MutableSettings.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================
--- cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/MutableSettings.java (original)
+++ cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/MutableSettings.java Sun Mar 26 03:22:11 2006
@@ -610,49 +610,49 @@
         if ( key.startsWith(KEYPREFIX) ) {
             final String sKey = key.substring(KEYPREFIX.length());
             if ( sKey.equals(KEY_PROCESSOR_CLASS) ) {
-                value = this.processorClassName;
+                value = this.getProcessorClassName();
             } else if ( sKey.equals(KEY_CONFIGURATION) ) {
-                value = this.configuration;
+                value = this.getConfiguration();
             } else if ( sKey.equals(KEY_RELOAD_DELAY) ) {
-                value = String.valueOf(this.configurationReloadDelay);
+                value = String.valueOf(this.getReloadDelay(null));
             } else if ( sKey.equals(KEY_LOGGING_CONFIGURATION) ) {
-                value = this.loggingConfiguration;
+                value = this.getLoggingConfiguration();
             } else if ( sKey.equals(KEY_LOGGING_ENVIRONMENT_LOGGER) ) {
-                value = this.environmentLogger;
+                value = this.getEnvironmentLogger();
             } else if ( sKey.equals(KEY_LOGGING_COCOON_LOGGER) ) {
-                value = this.cocoonLogger;
+                value = this.getCocoonLogger();
             } else if ( sKey.equals(KEY_LOGGING_BOOTSTRAP_LOGLEVEL) ) {
-                value = this.bootstrapLogLevel;
+                value = this.getBootstrapLogLevel();
             } else if ( sKey.equals(KEY_RELOADING) ) {
-                value = String.valueOf(this.reloadingEnabled);
+                value = String.valueOf(this.isReloadingEnabled(null));
             } else if ( sKey.equals(KEY_UPLOADS_ENABLE) ) {
-                value = String.valueOf(this.enableUploads);
+                value = String.valueOf(this.isEnableUploads());
             } else if ( sKey.equals(KEY_UPLOADS_DIRECTORY) ) {
-                value = this.uploadDirectory = value;
+                value = this.getUploadDirectory();
             } else if ( sKey.equals(KEY_UPLOADS_AUTOSAVE) ) {
-                value = String.valueOf(this.autosaveUploads);
+                value = String.valueOf(this.isAutosaveUploads());
             } else if ( sKey.equals(KEY_UPLOADS_OVERWRITE) ) {
-                value = this.overwriteUploads;
+                value = this.getOverwriteUploads();
             } else if ( sKey.equals(KEY_UPLOADS_MAXSIZE) ) {
-                value = String.valueOf(this.maxUploadSize);
+                value = String.valueOf(this.getMaxUploadSize());
             } else if ( sKey.equals(KEY_CACHE_DIRECTORY) ) {
-                value = this.cacheDirectory;
+                value = this.getCacheDirectory();
             } else if ( sKey.equals(KEY_WORK_DIRECTORY) ) {
-                value = this.workDirectory;
+                value = this.getWorkDirectory();
             } else if ( sKey.equals(KEY_SHOWTIME) ) {
-                value = String.valueOf(this.showTime);
+                value = String.valueOf(this.isShowTime());
             } else if ( sKey.equals(KEY_HIDE_SHOWTIME) ) {
-                value = String.valueOf(this.hideShowTime);
+                value = String.valueOf(this.isHideShowTime());
             } else if ( sKey.equals(KEY_MANAGE_EXCEPTIONS) ) {
-                value = String.valueOf(this.manageExceptions);
+                value = String.valueOf(this.isManageExceptions());
             } else if ( sKey.equals(KEY_FORM_ENCODING) ) {
-                value = this.formEncoding;
+                value = this.getFormEncoding();
             } else if ( sKey.equals(KEY_LOGGING_OVERRIDE_LOGLEVEL) ) {
-                value = this.overrideLogLevel;
+                value = this.getOverrideLogLevel();
             } else if ( key.equals(KEY_LOAD_CLASSES) ) {
-                value = this.toString(this.loadClasses);
+                value = this.toString(this.getLoadClasses());
             } else if ( key.equals(KEY_PROPERTY_PROVIDER) ) {
-                this.toString(this.propertyProviders);
+                value = this.toString(this.getPropertyProviders());
             }
         }
 
@@ -663,7 +663,11 @@
         }
 
         if ( value == null ) {
-            value = defaultValue;
+            if ( this.parent != null ) {
+                value = this.parent.getProperty(key, defaultValue);
+            } else {
+                value = defaultValue;
+            }
         }
         return value;
     }
@@ -717,28 +721,6 @@
     }
 
     /**
-     * Helper method to make a string out of a map of objects.
-     */
-    protected String toString(Map a) {
-        final StringBuffer buffer = new StringBuffer("{");
-        final Iterator i = a.entrySet().iterator();
-        boolean first = true;
-        while ( i.hasNext() ) {
-            if ( first ) {
-                first = false;
-            } else {
-                buffer.append(", ");
-            }
-            final Map.Entry current = (Map.Entry)i.next();
-            buffer.append(current.getKey());
-            buffer.append("=");
-            buffer.append(current.getValue());
-        }
-        buffer.append("}");
-        return buffer.toString();        
-    }
-
-    /**
      * @param hideShowTime The hideShowTime to set.
      */
     public void setHideShowTime(boolean hideShowTime) {
@@ -973,9 +955,9 @@
     }
 
     /**
-     * @see org.apache.cocoon.core.Settings#getProperties(java.lang.String)
+     * @see org.apache.cocoon.core.Settings#getPropertyNames(java.lang.String)
      */
-    public List getProperties(String keyPrefix) {
+    public List getPropertyNames(String keyPrefix) {
         final List props = new ArrayList();
         for(int i=0; i < this.properties.size(); i++) {
             final Properties p = (Properties)this.properties.get(i);
@@ -987,13 +969,23 @@
                 }
             }
         }
+        if ( this.parent != null ) {
+            final List parentList = this.parent.getPropertyNames(keyPrefix);
+            final Iterator i = parentList.iterator();
+            while ( i.hasNext() ) {
+                final String name = (String)i.next();
+                if ( !props.contains(name) ) {
+                    props.add(name);
+                }
+            }
+        }
         return props;
     }
     
     /**
-     * @see org.apache.cocoon.core.Settings#getProperties()
+     * @see org.apache.cocoon.core.Settings#getPropertyNames()
      */
-    public List getProperties() {
+    public List getPropertyNames() {
         final List props = new ArrayList();
         for(int i=0; i < this.properties.size(); i++) {
             final Properties p = (Properties)this.properties.get(i);
@@ -1001,6 +993,16 @@
             while ( kI.hasNext() ) {
                 final String name = (String)kI.next();
                 if (!props.contains(name) ) {
+                    props.add(name);
+                }
+            }
+        }
+        if ( this.parent != null ) {
+            final List parentList = this.parent.getPropertyNames();
+            final Iterator i = parentList.iterator();
+            while ( i.hasNext() ) {
+                final String name = (String)i.next();
+                if ( !props.contains(name) ) {
                     props.add(name);
                 }
             }

Modified: cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/Settings.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/Settings.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================
--- cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/BeanFactoryFactoryImpl.java (original)
+++ cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/BeanFactoryFactoryImpl.java Sun Mar 26 03:22:11 2006
@@ -80,8 +80,7 @@
             final ConfigurationInfo parentConfigInfo = (ConfigurationInfo) parentFactory
                     .getBean(ConfigurationInfo.class.getName());
             final ConfigurationInfo ci = ConfigReader.readConfiguration(config, parentConfigInfo, ae, resolver);
-    
-            return BeanFactoryUtil.createBeanFactory(ae, ci, parentFactory, false);
+            return BeanFactoryUtil.createBeanFactory(ae, ci, resolver, parentFactory, false);
         }
         return parentFactory;
     }

Modified: cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/BeanFactoryUtil.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/BeanFactoryUtil.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================
--- cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/BeanFactoryUtil.java (original)
+++ cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/BeanFactoryUtil.java Sun Mar 26 03:22:11 2006
@@ -19,32 +19,27 @@
 import java.net.URL;
 import java.util.Iterator;
 
-import javax.servlet.ServletConfig;
 import javax.servlet.ServletContext;
 
 import org.apache.avalon.excalibur.logger.Log4JConfLoggerManager;
 import org.apache.avalon.excalibur.logger.ServletLogger;
 import org.apache.avalon.framework.configuration.Configuration;
 import org.apache.avalon.framework.configuration.DefaultConfiguration;
-import org.apache.avalon.framework.context.Context;
 import org.apache.avalon.framework.context.DefaultContext;
 import org.apache.avalon.framework.logger.Logger;
 import org.apache.cocoon.ProcessingUtil;
 import org.apache.cocoon.acting.Action;
-import org.apache.cocoon.components.ContextHelper;
 import org.apache.cocoon.components.pipeline.ProcessingPipeline;
 import org.apache.cocoon.components.treeprocessor.ProcessorComponentInfo;
 import org.apache.cocoon.core.CoreInitializationException;
 import org.apache.cocoon.core.Settings;
 import org.apache.cocoon.core.container.util.ConfigurationBuilder;
 import org.apache.cocoon.core.container.util.SettingsContext;
-import org.apache.cocoon.environment.Request;
 import org.apache.cocoon.generation.Generator;
 import org.apache.cocoon.matching.Matcher;
 import org.apache.cocoon.reading.Reader;
 import org.apache.cocoon.selection.Selector;
 import org.apache.cocoon.serialization.Serializer;
-import org.apache.cocoon.servlet.CocoonServlet;
 import org.apache.cocoon.transformation.Transformer;
 import org.apache.excalibur.source.SourceResolver;
 import org.springframework.beans.factory.BeanFactory;
@@ -77,6 +72,7 @@
      */
     public static ConfigurableListableBeanFactory createBeanFactory(AvalonEnvironment env,
                                                                     ConfigurationInfo info,
+                                                                    SourceResolver    resolver,
                                                                     BeanFactory       parent,
                                                                     boolean           addCocoon)
     throws Exception {
@@ -95,6 +91,10 @@
         if ( info.rootLogger != null ) {
             factory.registerSingleton(Logger.class.getName(), logger);
         }
+        // add local resolver
+        if ( resolver != null ) {
+            factory.registerSingleton(SourceResolver.ROLE + "/Local", resolver);
+        }            
         prepareBeanFactory(factory, info);
         factory.preInstantiateSingletons();
         return factory;
@@ -255,43 +255,5 @@
         if ( component != null ) {
             info.setDefaultType(category, component.getDefaultValue());
         }
-    }
-
-    /**
-     * Build a bean factory with the contents of the &lt;map:components&gt; element of
-     * the tree.
-     */
-    public ConfigurableListableBeanFactory createBeanFactory(Logger         sitemapLogger,
-                                                             Configuration  config,
-                                                             Context        sitemapContext,
-                                                             SourceResolver resolver)
-    throws Exception {
-        // setup spring container
-        // first, get the correct parent
-        ConfigurableListableBeanFactory parentFactory = this.beanFactory;
-        final Request request = ContextHelper.getRequest(sitemapContext);
-        if (request.getAttribute(CocoonBeanFactory.BEAN_FACTORY_REQUEST_ATTRIBUTE, Request.REQUEST_SCOPE) != null) {
-            parentFactory = (ConfigurableListableBeanFactory) request
-                    .getAttribute(CocoonBeanFactory.BEAN_FACTORY_REQUEST_ATTRIBUTE, Request.REQUEST_SCOPE);
-        }
-
-        if ( config != null ) {
-            final AvalonEnvironment ae = new AvalonEnvironment();
-            ae.context = sitemapContext;
-            if ( sitemapLogger != null ) {
-                ae.logger = sitemapLogger;
-            } else {
-                ae.logger = (Logger)parentFactory.getBean(ProcessingUtil.LOGGER_ROLE);
-            }
-            ae.servletContext = ((ServletConfig) sitemapContext.get(CocoonServlet.CONTEXT_SERVLET_CONFIG))
-                    .getServletContext();
-            ae.settings = (Settings) this.beanFactory.getBean(Settings.ROLE);
-            final ConfigurationInfo parentConfigInfo = (ConfigurationInfo) parentFactory
-                    .getBean(ConfigurationInfo.class.getName());
-            final ConfigurationInfo ci = ConfigReader.readConfiguration(config, parentConfigInfo, ae, resolver);
-    
-            return BeanFactoryUtil.createBeanFactory(ae, ci, parentFactory, false);
-        }
-        return parentFactory;
     }
 }

Modified: cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/CocoonSettingsConfigurer.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/CocoonSettingsConfigurer.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================
--- cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/CocoonSettingsConfigurer.java (original)
+++ cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/CocoonSettingsConfigurer.java Sun Mar 26 03:22:11 2006
@@ -71,7 +71,7 @@
         public CocoonSettingsResolvingBeanDefinitionVisitor(Settings settings) {
             this.props = new Properties();
 
-            List propsList = settings.getProperties();
+            List propsList = settings.getPropertyNames();
             for (int i = 0; i < propsList.size(); i++) {
                 String propName = (String) propsList.get(i);
                 props.put(propName, settings.getProperty(propName));

Modified: cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/generation/StatusGenerator.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/generation/StatusGenerator.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================
--- cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/generation/StatusGenerator.java (original)
+++ cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/generation/StatusGenerator.java Sun Mar 26 03:22:11 2006
@@ -492,13 +492,13 @@
 
         this.addValue(Settings.KEY_RELOADING, s.isReloadingEnabled(null));
         this.addValue(Settings.KEY_RELOAD_DELAY, s.getReloadDelay(null));
-        Iterator i = s.getProperties("org.apache.cocoon." + Settings.KEY_RELOADING + '.').iterator();
+        Iterator i = s.getPropertyNames("org.apache.cocoon." + Settings.KEY_RELOADING + '.').iterator();
         while ( i.hasNext() ) {
             final String key = (String)i.next();
             final String value = s.getProperty(key);
             this.addValue(key.substring(18), value);
         }
-        i = s.getProperties("org.apache.cocoon." + Settings.KEY_RELOAD_DELAY + '.').iterator();
+        i = s.getPropertyNames("org.apache.cocoon." + Settings.KEY_RELOAD_DELAY + '.').iterator();
         while ( i.hasNext() ) {
             final String key = (String)i.next();
             final String value = s.getProperty(key);

Modified: cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/sitemap/impl/AbstractVirtualSitemapComponent.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/sitemap/impl/AbstractVirtualSitemapComponent.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================
--- cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/sitemap/impl/AbstractVirtualSitemapComponent.java (original)
+++ cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/sitemap/impl/AbstractVirtualSitemapComponent.java Sun Mar 26 03:22:11 2006
@@ -162,7 +162,8 @@
             // better be done in a constructor for the info.
             SitemapSourceInfo vpcEnvironmentInfo = new SitemapSourceInfo();
             vpcEnvironmentInfo.prefix = (String) this.context.get(Constants.CONTEXT_ENV_PREFIX);
-            vpcEnvironmentInfo.uri = (String) this.context.get(Constants.CONTEXT_ENV_URI);
+            // FIXME - What should the value of uri be?
+            vpcEnvironmentInfo.uri = "fixme";
             vpcEnvironmentInfo.requestURI = vpcEnvironmentInfo.prefix + vpcEnvironmentInfo.uri;
             vpcEnvironmentInfo.rawMode = false;
 

Modified: cocoon/trunk/cocoon-core/src/test/java/org/apache/cocoon/core/container/ContainerTestCase.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/test/java/org/apache/cocoon/core/container/ContainerTestCase.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================
--- cocoon/trunk/cocoon-core/src/test/java/org/apache/cocoon/core/container/ContainerTestCase.java (original)
+++ cocoon/trunk/cocoon-core/src/test/java/org/apache/cocoon/core/container/ContainerTestCase.java Sun Mar 26 03:22:11 2006
@@ -296,12 +296,12 @@
         this.rootBeanFactory = BeanFactoryUtil.createRootBeanFactory(avalonEnv);
         // read roles
         ConfigurationInfo rolesInfo = ConfigReader.readConfiguration(confRM, null, avalonEnv, null);
-        ConfigurableListableBeanFactory rolesContext = BeanFactoryUtil.createBeanFactory(avalonEnv, rolesInfo, this.rootBeanFactory, true);
+        ConfigurableListableBeanFactory rolesContext = BeanFactoryUtil.createBeanFactory(avalonEnv, rolesInfo, null, this.rootBeanFactory, true);
 
         // read components
         ConfigurationInfo componentsInfo = ConfigReader.readConfiguration(confCM, rolesInfo, avalonEnv, null);
         this.addComponents( componentsInfo );
-        ConfigurableListableBeanFactory componentsContext = BeanFactoryUtil.createBeanFactory(avalonEnv, componentsInfo, rolesContext, false);
+        ConfigurableListableBeanFactory componentsContext = BeanFactoryUtil.createBeanFactory(avalonEnv, componentsInfo, null, rolesContext, false);
 
         this.manager = (ServiceManager)componentsContext.getBean(ServiceManager.class.getName());
     }
--- cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/Settings.java (original)
+++ cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/Settings.java Sun Mar 26 03:22:11 2006
@@ -45,16 +45,16 @@
     String getProperty(String key, String defaultValue);
 
     /**
      * Return all available properties starting with the prefix.
      * @param keyPrefix The prefix each property name must have.
      * @return A list of property names (including the prefix) or
      *         an empty list.
      */
-    List getProperties(String keyPrefix);
+    List getPropertyNames(String keyPrefix);
     
     /**
-     * Return all available properties
+     * Return all available property names.
      * @return A list of all property names or an empty list.
      */
-    List getProperties();
+    List getPropertyNames();
 }
@@ -45,16 +45,16 @@
 
     /**
-     * Return all available properties starting with the prefix.
+     * Return all available property names starting with the prefix.
      * @param keyPrefix The prefix each property name must have.
      * @return A list of property names (including the prefix) or

Modified: cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/BeanFactoryFactoryImpl.java
URL: http://svn.apache.org/viewcvs/cocoon/trunk/cocoon-core/src/main/java/org/apache/cocoon/core/container/spring/BeanFactoryFactoryImpl.java?rev=388896&r1=388895&r2=388896&view=diff
==============================================================================